
#ifndef GPGMEPP_VERSION_H
#define GPGMEPP_VERSION_H

#define GPGMEPP_VERSION_STRING "5.3.2"
#define GPGMEPP_VERSION_MAJOR 5
#define GPGMEPP_VERSION_MINOR 3
#define GPGMEPP_VERSION_PATCH 2
#define GPGMEPP_VERSION ((5<<16)|(3<<8)|(2))

#endif
